class end_script():
    def end(self):
        while True:
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    sys.exit()
            clock.tick()
#start_script.start() fdgdshggfdhjkhsifdajgiudshjfguhdfbshui end_script.end()


from setuptools import setup,find_packages
setup(
    name='short_pygame',
    packages=find_packages(include=['short_pygame']),
    install_requires=["pygame"],
    author="Ivanchik burinki#4376 in discord",
    description="this is a plugin for shorten your pygame project description normal domain be soon"
)